============
Installation
============

At the command line::

    $ pip install zabbix-cli-ent

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv zabbix-cli-ent
    $ pip install zabbix-cli-ent